import type { FunctionComponent } from "react";
export type PropertyLineProps = {
    /**
     * The name of the property to display in the property line.
     */
    label: string;
    /**
     * Optional description for the property, shown on hover of the info icon
     */
    description?: string;
    /**
     * Optional function returning a string to copy to clipboard.
     */
    onCopy?: () => string;
    /**
     * If supplied, an 'expand' icon will be shown which, when clicked, renders this component within the property line.
     */
    expandedContent?: JSX.Element;
    /**
     * Link to the documentation for this property, available from the info icon either linked from the description (if provided) or defalt 'docs' text
     */
    docLink?: string;
};
export declare const LineContainer: import("react").ForwardRefExoticComponent<{
    children?: import("react").ReactNode | undefined;
} & import("react").RefAttributes<HTMLDivElement>>;
export type BaseComponentProps<T> = {
    /**
     * The value of the property to be displayed and modified.
     */
    value: T;
    /**
     * Callback function to handle changes to the value
     */
    onChange: (value: T) => void;
    /**
     * Optional flag to disable the component, preventing any interaction.
     */
    disabled?: boolean;
    /**
     * Optional class name to apply custom styles to the component.
     */
    className?: string;
};
/**
 * A reusable component that renders a property line with a label and child content, and an optional description, copy button, and expandable section.
 *
 * @param props - The properties for the PropertyLine component.
 * @returns A React element representing the property line.
 *
 */
export declare const PropertyLine: import("react").ForwardRefExoticComponent<PropertyLineProps & {
    children?: import("react").ReactNode | undefined;
} & import("react").RefAttributes<HTMLDivElement>>;
export declare const PlaceholderPropertyLine: FunctionComponent<BaseComponentProps<any> & PropertyLineProps>;
