import type { FunctionComponent } from "react";
import type { BaseComponentProps, PropertyLineProps } from "./propertyLine.js";
import { Vector4 } from "@babylonjs/core/Maths/math.vector.js";
import type { Vector3 } from "@babylonjs/core/Maths/math.vector.js";
export type VectorPropertyLineProps<V extends Vector3 | Vector4> = BaseComponentProps<V> & PropertyLineProps & {
    /**
     * If passed, all sliders will use this for the min value
     */
    min?: number;
    /**
     * If passed, all sliders will use this for the max value
     */
    max?: number;
    /**
     * If passed, the UX will use the conversion functions to display/update values
     */
    valueConverter?: {
        /**
         * Will call from(val) before displaying in the UX
         */
        from: (val: number) => number;
        /**
         * Will call to(val) before calling onChange
         */
        to: (val: number) => number;
    };
};
type RotationVectorPropertyLineProps = VectorPropertyLineProps<Vector3> & {
    /**
     * Display angles as degrees instead of radians
     */
    useDegrees?: boolean;
};
export declare const RotationVectorPropertyLine: FunctionComponent<RotationVectorPropertyLineProps>;
export declare const Vector3PropertyLine: FunctionComponent<VectorPropertyLineProps<Vector3>>;
export declare const Vector4PropertyLine: FunctionComponent<VectorPropertyLineProps<Vector4>>;
export {};
