import { jsx as _jsx } from "react/jsx-runtime";
import { Dropdown as FluentDropdown, makeStyles, Option } from "@fluentui/react-components";
import { useEffect, useState } from "react";
const useDropdownStyles = makeStyles({
    dropdownOption: {
        textAlign: "right",
        minWidth: "40px",
    },
    optionsLine: {},
});
/**
 * Renders a fluent UI dropdown component for the options passed in, and an additional 'Not Defined' option if includeUndefined is set to true
 * @param props
 * @returns dropdown component
 */
export const Dropdown = (props) => {
    const classes = useDropdownStyles();
    const [options] = useState(props.includeUndefined ? [{ label: "<Not defined>", value: Number.NaN }, ...props.options] : props.options);
    const [defaultVal, setDefaultVal] = useState(props.includeUndefined && props.value === undefined ? Number.NaN : props.value);
    useEffect(() => {
        setDefaultVal(props.includeUndefined && props.value === undefined ? Number.NaN : props.value);
    }, [props.value]);
    return (_jsx(FluentDropdown, { size: "small", className: classes.dropdownOption, onOptionSelect: (evt, data) => {
            let value = typeof props.value === "number" ? Number(data.optionValue) : data.optionValue;
            setDefaultVal(value);
            if (props.includeUndefined && value === Number.NaN.toString()) {
                value = undefined;
            }
            props.onChange(value);
        }, value: options.find((o) => o.value === defaultVal)?.label, children: options.map((option) => (_jsx(Option, { className: classes.optionsLine, value: option.value?.toString(), disabled: false, children: option.label }, option.label))) }));
};
//# sourceMappingURL=dropdown.js.map